AccessibilitySettings

Struct AccessibilitySettings 

pub struct AccessibilitySettings {
    pub audio_description: Option<bool>,
    pub screen_reader: Option<bool>,
    pub color_inversion: Option<bool>,
    pub enable_magnification: Option<bool>,
    pub color_correction: Option<ColorBlindnessType>,
    pub captions_settings: Option<CaptionsSettings>,
    /* private fields */
}
Supported accessibility settings.

Fields

audio_description: Option<bool>

For videos, use an alternative audio track (akin to changing languages) that explains what is happening visually while there is no dialogue.

screen_reader: Option<bool>

Read aloud elements of the screen selected by the user.

color_inversion: Option<bool>

Invert colors on the screen.

enable_magnification: Option<bool>

Interpret triple-tap on the touchscreen as a command to zoom in.

color_correction: Option<ColorBlindnessType>

What type of color-blindness, if any, to correct for.

captions_settings: Option<CaptionsSettings>

What kind of sources get closed captions, and how they look.