CaptionsSettings

Struct CaptionsSettings 

pub struct CaptionsSettings {
    pub for_media: Option<bool>,
    pub for_tts: Option<bool>,
    pub font_style: Option<CaptionFontStyle>,
    pub window_color: Option<ColorRgba>,
    pub background_color: Option<ColorRgba>,
    /* private fields */
}
What kind of sources get closed captions, and how they look.

Fields

for_media: Option<bool>

Closed captions enabled for media sources of audio.

for_tts: Option<bool>

Closed captions enabled for Text-To-Speech sources of audio.

font_style: Option<CaptionFontStyle>

Font style and color used for the closed captions text.

window_color: Option<ColorRgba>

Border color used around the closed captions window.

Each color channel should be a finite number otherwise will cause SetAccessibilityInfo to fail with INVALID_VALUE.

background_color: Option<ColorRgba>

Background color of the closed captions window.

Each color channel should be a finite number otherwise will cause SetAccessibilityInfo to fail with INVALID_VALUE.