DoNotDisturbSettings

Struct DoNotDisturbSettings 

pub struct DoNotDisturbSettings {
    pub user_initiated_do_not_disturb: Option<bool>,
    pub night_mode_initiated_do_not_disturb: Option<bool>,
    /* private fields */
}
Settings related to do-not-disturb (DND) mode.

Fields

user_initiated_do_not_disturb: Option<bool>

If true, the device is in do-not-disturb (DND) mode. Change this value if you’re directly responding to a user-initiated event.

Note that the device could still be in DND mode even if this is set to false, as [night_mode_initiated_do_not_disturb] might be true. To actually disable DND mode, set both fields to false.

To know whether DND is enabled, you need to do a boolean OR of both fields.

night_mode_initiated_do_not_disturb: Option<bool>

If true, the device is in do-not-disturb (DND) mode. Change this value if you’re trying to enable or disable DND based on a nightly schedule.

Note that the device could still be in DND mode even if this is set to false, as [user_initiated_do_not_disturb] might be true. Do not set that field to false unless you’re directly responding to a user-initiated event.

To know whether DND is enabled, you need to do a boolean OR of both fields.