Volume

Struct Volume 

pub struct Volume {
    pub level: Option<f32>,
    pub muted: Option<bool>,
    /* private fields */
}

Fields

level: Option<f32>

The volume level ranged [0.0, 1.0]. The level maps to a dbfs value from a volume curve in the setting service. Not a number (NaN), infinity or negative infinity will cause SetVolume to fail with INVALID_VALUE.

muted: Option<bool>

True if the volume should be muted. If this is true, then the volume is silent, regardless of level.